==> cuor-order-chaining-consumer-1.0.0.tgz: package/src/conifg/env.ts <==
import { cleanEnv, str, url } from "envalid";

interface Env {
  APP_NAME: string;
  AUTH_URL: string;
  AUTH_CLIENT_ID: string;
  AUTH_CLIENT_SECRET: string;
  DEPLOYMENT_ENVIRONMENT: string;
  KAFKA_BOOTSTRAP_SERVERS: string;
  KAFKA_PASSWORD: string;
  KAFKA_SASL_MECHANISM: "plain" | "scram-sha-512";
  KAFKA_SOURCE_TOPIC_NAME: string;
  KAFKA_USERNAME: string;
  LOGGER_LEVEL: string;
  USX_DATA_BRIDGE_API: string;
  USX_DATA_BRIDGE_KEY: string;
}


export const env: Env = cleanEnv(process.env, {
  APP_NAME: str({
    default: "cuor-order-chaining-consumer",
    devDefault: "cuor-order-chaining-consumer"
  }),
  AUTH_URL: url({
    default: "https://auth.haulynx.io",
    devDefault: "https://auth-dev.haulynx.io"
  }),
  AUTH_CLIENT_ID: str({
    default: "defaultValue",
    devDefault: "defaultValue"
  }),
  AUTH_CLIENT_SECRET: str({
    default: "defaultValue",
    devDefault: "defaultValue"
  }),
  DEPLOYMENT_ENVIRONMENT: str({
    default: "prod",
    devDefault: "dev"
  }),
  KAFKA_BOOTSTRAP_SERVERS: str({
    default: "127.0.0.1",
    devDefault: "127.0.0.1",
    desc: "Comma separated list of kafka broker URLs"
  }),
  KAFKA_PASSWORD: str({
    default: "admin",
    devDefault: "admin"
  }),
  KAFKA_SASL_MECHANISM: str({
    default: "plain",
    devDefault: "plain"
  }),
  KAFKA_SOURCE_TOPIC_NAME: str({
    default: "stage_bus_iohaulynx_usxorder_event_json",
    devDefault: "dev_bus_iohaulynx_usxorder_event_json",
    desc: "Kafka topic name we will be subscribing to"
  }),
  KAFKA_USERNAME: str({
    default: "admin",
    devDefault: "admin"
  }),
  LOGGER_LEVEL: str({
    default: "error",
    devDefault: "error",
    desc: "The logging threshold level (default level is 'info'). Choices are 'trace', 'debug', 'info', 'warn', 'error', 'fatal'."
  }),
  USX_DATA_BRIDGE_KEY: str({
    default: "defaultValue",
    devDefault: "defaultValue"
  }),
  USX_DATA_BRIDGE_API: url({
    default: "https://api.haulynx.com/orderBridge-stage",
    devDefault: "https://api.haulynx.com/orderBridge-dev"
  })
});

==> cuor-order-chaining-consumer-1.1.0.tgz: package/src/conifg/env.ts <==
import { cleanEnv, str, url } from "envalid";

interface Env {
  APP_NAME: string;
  AUTH_URL: string;
  AUTH_CLIENT_ID: string;
  AUTH_CLIENT_SECRET: string;
  AUD_USX_DATA_BRIDGE: string;
  DEPLOYMENT_ENVIRONMENT: string;
  KAFKA_BOOTSTRAP_SERVERS: string;
  KAFKA_PASSWORD: string;
  KAFKA_SASL_MECHANISM: "plain" | "scram-sha-512";
  KAFKA_SOURCE_TOPIC_NAME: string;
  KAFKA_USERNAME: string;
  LOGGER_LEVEL: string;
  MISSION_MANAGEMENT_API_URL: string;
  USX_DATA_BRIDGE_API_URL: string;
  USX_DATA_BRIDGE_API_KEY: string;
}


export const env: Env = cleanEnv(process.env, {
  APP_NAME: str({
    default: "cuor-order-chaining-consumer",
    devDefault: "cuor-order-chaining-consumer"
  }),
  AUTH_URL: url({
    default: "https://auth.haulynx.io",
    devDefault: "https://auth-dev.haulynx.io"
  }),
  AUTH_CLIENT_ID: str({
    default: "defaultValue",
    devDefault: "defaultValue"
  }),
  AUTH_CLIENT_SECRET: str({
    default: "defaultValue",
    devDefault: "defaultValue"
  }),
  AUD_USX_DATA_BRIDGE: str({
    default: "https://api.haulynx.com/orderBridge-prod",
    devDefault: "https://api.haulynx.com/orderBridge-dev"
  }),
  DEPLOYMENT_ENVIRONMENT: str({
    default: "prod",
    devDefault: "dev"
  }),
  KAFKA_BOOTSTRAP_SERVERS: str({
    default: "pkc-4nym6.us-east-1.aws.confluent.cloud:9092",
    desc: "Comma separated list of kafka broker URLs"
  }),
  KAFKA_PASSWORD: str({
    default: "admin",
    devDefault: "admin"
  }),
  KAFKA_SASL_MECHANISM: str({
    default: "plain",
    devDefault: "plain"
  }),
  KAFKA_SOURCE_TOPIC_NAME: str({
    default: "stage_bus_iohaulynx_usxorder_event_json",
    devDefault: "dev_bus_iohaulynx_usxorder_event_json",
    desc: "Kafka topic name we will be subscribing to"
  }),
  KAFKA_USERNAME: str({
    default: "admin",
    devDefault: "admin"
  }),
  LOGGER_LEVEL: str({
    default: "error",
    devDefault: "trace",
    desc: "The logging threshold level (default level is 'info'). Choices are 'trace', 'debug', 'info', 'warn', 'error', 'fatal'."
  }),
  MISSION_MANAGEMENT_API_URL: str({
    default: "https://cuor-mission-management-api-prod.internal.ue1.haulynx.io",
    devDefault: "https://cuor-mission-management-api-dev.internal.ue1.haulynx.io"
  }),
  USX_DATA_BRIDGE_API_KEY: str({
    default: "defaultValue",
    devDefault: "defaultValue"
  }),
  USX_DATA_BRIDGE_API_URL: url({
    default: "https://cuor-usx-data-bridge-api.internal.ue1.haulynx.io",
    devDefault: "https://cuor-usx-data-bridge-api-dev.internal.ue1.haulynx.io"
  })
});
